@@ -140,7 +140,6 @@ struct ViewMainPagePrivate
     DocumentViewSynchronizer* mSynchronizer;
     QToolButton* mToggleSideBarButton;
     QToolButton* mToggleThumbnailBarButton;
-    QToolButton* mLockZoomButton;
     ZoomWidget* mZoomWidget;
     DocumentViewContainer* mDocumentViewContainer;
     SlideContainer* mToolContainer;
@@ -286,11 +285,6 @@ struct ViewMainPagePrivate
         mZoomWidget = new ZoomWidget;
         mSynchronizeCheckBox = new QCheckBox(i18n("Synchronize"));
         mSynchronizeCheckBox->hide();
-        mLockZoomButton = new QToolButton;
-        mLockZoomButton->setAutoRaise(true);
-        mLockZoomButton->setCheckable(true);
-        q->updateLockZoomButton();
-        QObject::connect(mLockZoomButton, SIGNAL(toggled(bool)), q, SLOT(updateLockZoomButton()));
 
         QHBoxLayout* layout = new QHBoxLayout(mStatusBarContainer);
         layout->setMargin(0);
@@ -301,7 +295,6 @@ struct ViewMainPagePrivate
         layout->addWidget(mSynchronizeCheckBox);
         layout->addStretch();
         layout->addWidget(mZoomWidget);
-        layout->addWidget(mLockZoomButton);
     }
 
     void setupSplitter()
@@ -452,9 +445,9 @@ void ViewMainPage::loadConfig()
     }
 
     if (GwenviewConfig::showLockZoomButton()) {
-        d->mLockZoomButton->setChecked(GwenviewConfig::lockZoom());
+        d->mZoomWidget->setZoomLocked(GwenviewConfig::lockZoom());
     } else {
-        d->mLockZoomButton->hide();
+        d->mZoomWidget->setLockZoomButtonVisible(false);
     }
 }
 
@@ -463,7 +456,7 @@ void ViewMainPage::saveConfig()
     d->saveSplitterConfig();
     GwenviewConfig::setThumbnailBarIsVisible(d->mToggleThumbnailBarAction->isChecked());
     if (GwenviewConfig::showLockZoomButton()) {
-        GwenviewConfig::setLockZoom(d->mLockZoomButton->isChecked());
+        GwenviewConfig::setLockZoom(d->mZoomWidget->isZoomLocked());
     }
 }
 
@@ -611,7 +604,7 @@ void ViewMainPage::openUrls(const KUrl::List& allUrls, const KUrl& currentUrl)
     typedef QMap<KUrl, DocumentView*> ViewForUrlMap;
     ViewForUrlMap viewForUrlMap;
 
-    if (!d->mDocumentViews.isEmpty() && GwenviewConfig::showLockZoomButton() && d->mLockZoomButton->isChecked()) {
+    if (!d->mDocumentViews.isEmpty() && d->mZoomWidget->isZoomLocked()) {
         setup = d->mDocumentViews.last()->setup();
     } else {
         setup.valid = true;
@@ -763,9 +756,4 @@ void ViewMainPage::showMessageWidget(QGraphicsWidget* widget, Qt::Alignment alig
     d->mDocumentViewContainer->showMessageWidget(widget, align);
 }
 
-void ViewMainPage::updateLockZoomButton()
-{
-    d->mLockZoomButton->setIcon(KIcon(d->mLockZoomButton->isChecked() ? "object-locked" : "object-unlocked"));
-}
-
 } // namespace
