@@ -181,8 +181,10 @@ struct LoadingDocumentImplPrivate
         QBuffer buffer;
         buffer.setBuffer(&mData);
         buffer.open(QIODevice::ReadOnly);
+        LOG("mFormatHint" << mFormatHint);
         QImageReader reader(&buffer, mFormatHint);
         if (!reader.canRead()) {
+            kError() << "QImageReader::read() failed:" << reader.errorString();
             return false;
         }
         mFormat = reader.format();
@@ -191,6 +193,7 @@ struct LoadingDocumentImplPrivate
             // Gwenview code assumes JPEG images have "jpeg" format.
             mFormat = "jpeg";
         }
+        LOG("mFormat" << mFormat);
         if (mFormat.isEmpty()) {
             kError() << "mFormat.isEmpty(): this should not happen!";
             return false;
@@ -334,8 +337,8 @@ void LoadingDocumentImpl::init()
     } else {
         // Transfer file via KIO
         d->mTransferJob = KIO::get(document()->url());
-        connect(d->mTransferJob, SIGNAL(data(KIO::Job*, QByteArray)),
-                SLOT(slotDataReceived(KIO::Job*, QByteArray)));
+        connect(d->mTransferJob, SIGNAL(data(KIO::Job*,QByteArray)),
+                SLOT(slotDataReceived(KIO::Job*,QByteArray)));
         connect(d->mTransferJob, SIGNAL(result(KJob*)),
                 SLOT(slotTransferFinished(KJob*)));
         d->mTransferJob->start();
