@@ -47,7 +47,7 @@ class GWENVIEWLIB_EXPORT DocumentViewSynchronizer : public QObject
 public:
     // We pass a pointer to the view list because we don't want to maintain
     // a copy of the list itself
-    DocumentViewSynchronizer(const QList<DocumentView*>* views, QObject* parent = 0);
+    explicit DocumentViewSynchronizer(const QList<DocumentView*>* views, QObject* parent = 0);
     ~DocumentViewSynchronizer();
 
     void setCurrentView(DocumentView* view);
